@@ -25,7 +25,7 @@ __all__ = (
 )
 
 
-__version__ = '0.2.4'
+__version__ = '0.3.0'
 
 
 def is_number(number):
@@ -349,6 +349,12 @@ class AbstractInterval(object):
             and not (self.lower_inc and self.upper_inc)
         )
 
+    def __bool__(self):
+        return not self.empty
+
+    def __nonzero__(self):
+        return not self.empty
+
     @property
     def centre(self):
         return float((self.lower + self.upper)) / 2
@@ -519,6 +525,16 @@ class IntInterval(NumberInterval):
             return int(obj)
         return obj
 
+    def __int__(self):
+        if self.empty:
+            raise TypeError('Empty intervals cannot be coerced to integers')
+        if self.lower != self.upper:
+            raise TypeError(
+                'Only intervals containing single point can be coerced to'
+                ' integers'
+            )
+        return self.lower
+
 
 class DateInterval(AbstractInterval):
     step = timedelta(days=1)
