@@ -83,12 +83,14 @@ class TestIntervalInit(object):
 
     def test_supports_integers(self):
         interval = IntInterval(3)
+        assert interval.lower.__class__ == int
         assert interval.lower == 3
         assert interval.upper == 3
         assert interval.lower_inc
         assert interval.upper_inc
 
-    @mark.parametrize(('number_range', 'lower', 'upper'),
+    @mark.parametrize(
+        ('number_range', 'lower', 'upper'),
         (
             ('-2-2', -2, 2),
             ('-3--2', -3, -2),
@@ -102,7 +104,8 @@ class TestIntervalInit(object):
         assert interval.lower == lower
         assert interval.upper == upper
 
-    @mark.parametrize('number_range',
+    @mark.parametrize(
+        'number_range',
         (
             (3, 2),
             [4, 2],
@@ -117,7 +120,8 @@ class TestIntervalInit(object):
 
 
 class TestTypeGuessing(object):
-    @mark.parametrize(('number_range', 'type'),
+    @mark.parametrize(
+        ('number_range', 'type'),
         (
             ((2, 3), int),
             ([-6, 8], int),
